@@ -2,16 +2,18 @@ import dataclasses
 import json
 import logging
 import struct
-from _decimal import Decimal
 from datetime import date, datetime
-from typing import Any
+from decimal import Decimal
+from typing import Any, Type, TypeVar
 
 from msgspec import msgpack
 from msgspec.msgpack import Ext, encode
+from pydantic import BaseModel
 
 from python3_commons.serializers.json import CustomJSONEncoder
 
 logger = logging.getLogger(__name__)
+T = TypeVar('T')
 
 
 def enc_hook(obj: Any) -> Any:
@@ -45,28 +47,44 @@ MSGPACK_DECODER = msgpack.Decoder(ext_hook=ext_hook)
 MSGPACK_DECODER_NATIVE = msgpack.Decoder()
 
 
-def serialize_msgpack_native(data) -> bytes:
-    return encode(data)
+def serialize_msgpack_native(data: Any) -> bytes:
+    if isinstance(data, BaseModel):
+        data = data.model_dump()
+
+    result = encode(data)
+
+    return result
 
 
-def deserialize_msgpack_native(data: bytes, data_type=None):
+def deserialize_msgpack_native(data: bytes, data_type: Type[T] | None = None) -> T | Any:
     if data_type:
-        result = msgpack.decode(data, type=data_type)
+        if issubclass(data_type, BaseModel):
+            decoded = MSGPACK_DECODER_NATIVE.decode(data)
+            result = data_type.model_validate(decoded)
+        else:
+            result = msgpack.decode(data, type=data_type)
     else:
         result = MSGPACK_DECODER_NATIVE.decode(data)
 
     return result
 
 
-def serialize_msgpack(data) -> bytes:
+def serialize_msgpack(data: Any) -> bytes:
+    if isinstance(data, BaseModel):
+        data = data.model_dump()
+
     result = MSGPACK_ENCODER.encode(data)
 
     return result
 
 
-def deserialize_msgpack(data: bytes, data_type=None):
+def deserialize_msgpack(data: bytes, data_type: Type[T] | None = None) -> T | Any:
     if data_type:
-        result = msgpack.decode(data, type=data_type)
+        if issubclass(data_type, BaseModel):
+            decoded = MSGPACK_DECODER.decode(data)
+            result = data_type.model_validate(decoded)
+        else:
+            result = msgpack.decode(data, type=data_type)
     else:
         result = MSGPACK_DECODER.decode(data)
 
